==> bacula-docs-3.0.0.tar.bz2: bacula-docs-3.0.0/home-page/en/pages/home.php <==
<? require_once("inc/header.php"); ?>
<table>
<tr>
   <td class="contentTopic">
      Bacula&reg; - The Open Source Network Backup Solution
   </td>
</tr>
<tr>
  <td class="content">
     <b>Bacula</b> is a set of Open Source, enterprise ready,
     computer programs that permit you (or the system
     administrator) to manage backup, recovery, and verification
     of computer data across a network of computers of different
     kinds.<br>

     <br>     
     In technical terms, it is an <b>Open Source, enterprise
     ready, network based backup program</b>.<br>

     <br>
     Kern Sibbald announces the creation of Bacula Systems SA to provide
     professional services to Bacula users. See: 
     <a href="http://www.bacula.org/en/?page=news">
     News </a><br>

     <br>
     Bacula is relatively easy to use and efficient, while
     offering many advanced storage management features that make
     it easy to find and recover lost or damaged files.<br> 

     <br>
     Most of the <b>Bacula</b> source code is released under the
     <b>GPL</b> version 2 license.  If you wish additional
     details, please follow the License link to your left.<br>

     <br>The Documentation link takes you to a page where you
     can access all the available Bacula documentation (HTML,
     PDF, and TGZ) both for the officially released version 
     and for the current code under development in the Source
     Forge SVN. The development version of the manual typically has
     more documentation, but may also document new features that are
     not in the released version.  The Developer's Guide
     presents important information for users who want to
     contribute to the Bacula project.<br>  
        
     <br> Bacula is Hosted on
     SourceForge at <a href="http://sourceforge.net/projects/bacula">
     http://sourceforge.net/projects/bacula </a> where you can
     download the software.<br> <br> You may also use
     the links on the left side of this page for more
     information.  In particular, Current Files link takes
     you to the currently available downloads, and the All
     Downloads link takes you to a list of all files ever
     released to SourceForge.
  </td>
</tr>
</table>

<? require_once("inc/footer.php"); ?>

==> bacula-docs-3.0.1.tar.bz2: bacula-docs-3.0.1/home-page/en/pages/home.php <==
<? require_once("inc/header.php"); ?>
<table>
<tr>
   <td class="contentTopic">
      Bacula&reg; - The Open Source Network Backup Solution
   </td>
</tr>
<tr>
  <td class="content">
     <b>Bacula</b> is a set of Open Source, enterprise ready,
     computer programs that permit you (or the system
     administrator) to manage backup, recovery, and verification
     of computer data across a network of computers of different
     kinds.<br>

     <br>     
     In technical terms, it is an <b>Open Source, enterprise
     ready, network based backup program</b>.<br>

     <br>
     Bacula 3.0.0 is released.
     See: <a href="http://www.bacula.org/en/?page=news">
     News </a><br>

     <br>
     Bacula is relatively easy to use and efficient, while
     offering many advanced storage management features that make
     it easy to find and recover lost or damaged files.<br> 

     <br>
     Most of the <b>Bacula</b> source code is released under the
     <b>GPL</b> version 2 license.  If you wish additional
     details, please follow the License link to your left.<br>

     <br>The Documentation link takes you to a page where you
     can access all the available Bacula documentation (HTML,
     PDF, and TGZ) both for the officially released version 
     and for the current code under development in the Source
     Forge SVN. The development version of the manual typically has
     more documentation, but may also document new features that are
     not in the released version.  The Developer's Guide
     presents important information for users who want to
     contribute to the Bacula project.<br>  
        
     <br>Bacula is released on
     SourceForge at <a href="http://sourceforge.net/projects/bacula">
     http://sourceforge.net/projects/bacula </a> where you can
     download the software.<br> <br> You may also use
     the links on the left side of this page for more
     information.  In particular, Current Files link takes
     you to the currently available downloads, and the All
     Downloads link takes you to a list of all files ever
     released to SourceForge.
  </td>
</tr>
</table>

<? require_once("inc/footer.php"); ?>
